==> java-client-2.0.0-sources.jar: com/couchbase/client/java/ReplicaMode.java <==
/**
 * Copyright (C) 2014 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.java;

/**
 * Represents the different modes to read from replica nodes.
 *
 * @author Michael Nitschinger
 * @since 2.0
 */
public enum ReplicaMode {

    /**
     * Get from all replicas and the active node.
     */
    ALL,

    /**
     * Get only from the first replica configured for the document.
     */
    FIRST,

    /**
     * Get only from the second replica configured for the document.
     */
    SECOND,

    /**
     * Get only from the third replica configured for the document.
     */
    THIRD
}

==> java-client-2.2.1-sources.jar: com/couchbase/client/java/ReplicaMode.java <==
/**
 * Copyright (C) 2014 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.java;

/**
 * Represents the different modes to read from replica nodes.
 *
 * @author Michael Nitschinger
 * @since 2.0
 */
public enum ReplicaMode {

    /**
     * Get from all replicas and the active node.
     */
    ALL(4),

    /**
     * Get only from the first replica configured for the document.
     */
    FIRST(1),

    /**
     * Get only from the second replica configured for the document.
     */
    SECOND(1),

    /**
     * Get only from the third replica configured for the document.
     */
    THIRD(1);

    private int maxAffectedNodes;

    ReplicaMode(int maxAffectedNodes) {
        this.maxAffectedNodes = maxAffectedNodes;
    }

    public int maxAffectedNodes() {
        return maxAffectedNodes;
    }
}
